@@ -1,28 +1,21 @@
-extern crate pointprocesses;
-extern crate plotlib;
-extern crate svg;
-
-#[macro_use]
-extern crate ndarray;
-
 use std::fs;
 
-use plotlib::style::{PointStyle, PointMarker};
-use plotlib::view;
-use plotlib::page;
-use plotlib::repr::Scatter;
-
+use ndarray::{array, s};
 use ndarray::{Array1, Array2};
 
 use pointprocesses::spatial::*;
 
-static MARKER_COLOR: &str = "#C93E3E";
+use plotters::prelude::*;
+
+static IMG_SIZE: (u32, u32) = (480, 480);
+static TITLE_FONT: &str = "Arial";
 
 
-fn main() {
+fn main() -> Result<(), Box<dyn std::error::Error>> {
     fs::create_dir("lib/examples/images").unwrap_or_default();
-    square_example();
-    variable_circle_example();
+    square_example()?;
+    variable_circle_example()?;
+    Ok(())
 }
 
 /// The `plotlib` library expects vectors of tuples for input.
@@ -34,7 +27,7 @@ fn cast_to_tuples(arr: Array2<f64>) -> Vec<(f64,f64)> {
     }).collect()
 }
 
-fn square_example() {
+fn square_example() -> Result<(), Box<dyn std::error::Error>> {
     let lambda = 200.0;
 
     let close = array![0.0,0.0];
@@ -51,26 +44,35 @@ fn square_example() {
 
     let data = cast_to_tuples(events);
 
-    // We create our scatter plot from the data$
-    let s1 = Scatter::from_slice(&data)
-        .style(PointStyle::new()
-            .marker(PointMarker::Circle) // setting the marker to be a square
-            .colour(MARKER_COLOR)
-            .size(2.5)); // and a custom colour 
-    
-    let v = view::ContinuousView::new()
-        .add(s1)
-        .x_range(0., 1.)
-        .y_range(0., 1.)
-        .x_label("x")
-        .y_label("y");
-    
-    page::Page::single(&v)
-        .dimensions(600, 600)
-        .save("lib/examples/images/2d_poisson.rect.svg").unwrap();
+    let root = BitMapBackend::new(
+        "lib/examples/images/2d_poisson_rect.png", IMG_SIZE)
+        .into_drawing_area();
+
+    root.fill(&WHITE)?;
+
+    let chart_title = "2D Poisson process";
+    let mut chart = ChartBuilder::on(&root)
+        .caption(chart_title, (TITLE_FONT, 16).into_font())
+        .margin(5)  
+        .x_label_area_size(30)
+        .y_label_area_size(30)
+        .build_ranged(0.0..1.0, 0.0..1.0)?;
+
+    chart.configure_mesh().draw()?;
+
+    let size = 2;
+    chart.draw_series(
+        data.iter()
+            .map(|(x,y)| {
+                Circle::new((*x, *y), size,
+                RED.filled())
+            })   
+    )?;
+
+    Ok(())
 }
 
-fn variable_circle_example() {
+fn variable_circle_example() -> Result<(), Box<dyn std::error::Error>> {
     let close: Array1<f64> = array![0.,0.];
     let far = array![1.,1.];
     let domain = Domain::new(close, far);
@@ -101,22 +103,31 @@ fn variable_circle_example() {
 
     let data = cast_to_tuples(events);
 
-    // We create our scatter plot from the data
-    let s = Scatter::from_slice(&data)
-        .style(PointStyle::new()
-            .marker(PointMarker::Circle)
-            .colour(MARKER_COLOR)
-            .size(1.2)); // and a custom colour
+    let root = BitMapBackend::new(
+        "lib/examples/images/2d_poisson_circle.png", IMG_SIZE)
+        .into_drawing_area();
 
-    // The 'view' describes what set of data is drawn
-    let v = view::ContinuousView::new()
-        .add(s)
-        .x_range(0., 1.)
-        .y_range(0., 1.)
-        .x_label("x")
-        .y_label("y");
+    root.fill(&WHITE)?;
+
+    let chart_title = "2D Poisson process";
+    let mut chart = ChartBuilder::on(&root)
+        .caption(chart_title, (TITLE_FONT, 16).into_font())
+        .margin(5)
+        .x_label_area_size(30)
+        .y_label_area_size(30)
+        .build_ranged(0.0..1.0, 0.0..1.0)?;
+
+    chart.configure_mesh().draw()?;
+
+    let size = 2;
+    chart.draw_series(
+        data.iter()
+            .map(|(x,y)| {
+                Circle::new((*x, *y), size,
+                RED.filled())
+            })   
+    )?;
+
+    Ok(())
 
-    page::Page::single(&v)
-        .dimensions(600, 600)
-        .save("lib/examples/images/2d_poisson.variable.circle.svg").unwrap();
 }
